==> classpath-0.16.tar.gz: classpath-0.16/org/omg/Dynamic/Parameter.java <==
/* Parameter.java --
   Copyright (C) 2005 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package org.omg.Dynamic;

import org.omg.CORBA.Any;
import org.omg.CORBA.ParameterMode;
import org.omg.CORBA.portable.IDLEntity;

import java.io.Serializable;

/**
 * When representing the information about a request,
 * defines a one of the arguments for the operation being invoked.
 *
 * @see org.omg.PortableInterceptor.RequestInfoOperation#arguments()
 *
 * @author Audrius Meskauskas, Lithuania (AudriusA@Bioinformatics.org)
 */
public class Parameter
  implements IDLEntity, Serializable
{
  /**
   * Use serialVersionUID (v1.4) for interoperability.
   */
  private static final long serialVersionUID = 892191606993734699L;

  /**
   * The {@link Any}, holding the value of the parameter.
   */
  public Any argument;

  /**
   * The mode of the parameter. Specifies if the parameter is used
   * to pass the value to the method, to return the value from the
   * method or for both of these purposes.
   */
  public ParameterMode mode;

  /**
   * Create the unitialised instance.
   */
  public Parameter()
  {
  }

  /**
   * Create an instance, initialising field to the passed values.
   */
  public Parameter(Any an_argument, ParameterMode a_mode)
  {
    argument = an_argument;
    mode = a_mode;
  }
}

==> classpath-0.98.tar.gz: classpath-0.98/org/omg/Dynamic/Parameter.java <==
/* Parameter.java --
   Copyright (C) 2005, 2006 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package org.omg.Dynamic;

import org.omg.CORBA.Any;
import org.omg.CORBA.ParameterMode;
import org.omg.CORBA.portable.IDLEntity;

import java.io.Serializable;

/**
 * When representing the information about a request,
 * defines a one of the arguments for the operation being invoked.
 *
 * @see org.omg.PortableInterceptor.RequestInfoOperations#arguments()
 *
 * @author Audrius Meskauskas, Lithuania (AudriusA@Bioinformatics.org)
 */
public final class Parameter
  implements IDLEntity, Serializable
{
  /**
   * Use serialVersionUID (v1.4) for interoperability.
   */
  private static final long serialVersionUID = 892191606993734699L;

  /**
   * The {@link Any}, holding the value of the parameter.
   */
  public Any argument;

  /**
   * The mode of the parameter. Specifies if the parameter is used
   * to pass the value to the method, to return the value from the
   * method or for both of these purposes.
   */
  public ParameterMode mode;

  /**
   * Create the uninitialised instance.
   */
  public Parameter()
  {
  }

  /**
   * Create an instance, initialising field to the passed values.
   */
  public Parameter(Any an_argument, ParameterMode a_mode)
  {
    argument = an_argument;
    mode = a_mode;
  }
}
